==> kubernetes-model-networking-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressRuleValueFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPIngressRuleValueFluent<A extends HTTPIngressRuleValueFluent<A>> extends Fluent<A>{
  public A addToPaths(Integer index,HTTPIngressPath item);
  public A setToPaths(Integer index,HTTPIngressPath item);
  public A addToPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... items);
  public A addAllToPaths(Collection<HTTPIngressPath> items);
  public A removeFromPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... items);
  public A removeAllFromPaths(Collection<HTTPIngressPath> items);
  public A removeMatchingFromPaths(Predicate<HTTPIngressPathBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPaths instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPIngressPath> getPaths();
  public List<HTTPIngressPath> buildPaths();
  public HTTPIngressPath buildPath(Integer index);
  public HTTPIngressPath buildFirstPath();
  public HTTPIngressPath buildLastPath();
  public HTTPIngressPath buildMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public Boolean hasMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public A withPaths(List<HTTPIngressPath> paths);
  public A withPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... paths);
  public Boolean hasPaths();
  public HTTPIngressRuleValueFluent.PathsNested<A> addNewPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(HTTPIngressPath item);
  public HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(Integer index,HTTPIngressPath item);
  public HTTPIngressRuleValueFluent.PathsNested<A> editPath(Integer index);
  public HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> editLastPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathsNested<N> extends Nested<N>,HTTPIngressPathFluent<HTTPIngressRuleValueFluent.PathsNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}

==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressRuleValueFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPIngressRuleValueFluent<A extends HTTPIngressRuleValueFluent<A>> extends Fluent<A>{
  public A addToPaths(int index,HTTPIngressPath item);
  public A setToPaths(int index,HTTPIngressPath item);
  public A addToPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... items);
  public A addAllToPaths(Collection<HTTPIngressPath> items);
  public A removeFromPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... items);
  public A removeAllFromPaths(Collection<HTTPIngressPath> items);
  public A removeMatchingFromPaths(Predicate<HTTPIngressPathBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPaths instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPIngressPath> getPaths();
  public List<HTTPIngressPath> buildPaths();
  public HTTPIngressPath buildPath(int index);
  public HTTPIngressPath buildFirstPath();
  public HTTPIngressPath buildLastPath();
  public HTTPIngressPath buildMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public Boolean hasMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public A withPaths(List<HTTPIngressPath> paths);
  public A withPaths(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath... paths);
  public Boolean hasPaths();
  public HTTPIngressRuleValueFluent.PathsNested<A> addNewPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(HTTPIngressPath item);
  public HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(int index,HTTPIngressPath item);
  public HTTPIngressRuleValueFluent.PathsNested<A> editPath(int index);
  public HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> editLastPath();
  public HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(Predicate<HTTPIngressPathBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PathsNested<N> extends Nested<N>,HTTPIngressPathFluent<HTTPIngressRuleValueFluent.PathsNested<N>>{
    public N and();
    public N endPath();
    
  }
  
}
